define("jira/model/automation-service", ["jquery"], function ($) {
  return {
    baseServiceUrl: function () {
      return AJS.contextPath() + "/rest/automation/1.0/rule";
    },
    saveProjectConfig: function (param) {
      return $.ajax({
        type: "post",
        url: this.baseServiceUrl() + "/",
        dataType: 'json',
        data: JSON.stringify(param),
        contentType: "application/json; charset=utf-8"
      });
    },
    changeOrderNum: function (ruleId, position) {
      return $.ajax({
        type: "post",
        url: this.baseServiceUrl() + "/order-number/" + ruleId + "/" + position,
        dataType: 'json',
        contentType: "application/json; charset=utf-8"
      });
    },
    getConfig: function (ruleId) {
      return $.ajax({
        type: "get",
        url: this.baseServiceUrl() + "/" + ruleId,
        dataType: 'json',
        contentType: "application/json; charset=utf-8"
      });
    },
    getLogs: function (ruleId) {
      return $.ajax({
        type: "get",
        url: this.baseServiceUrl() + "/logs/" + ruleId,
        dataType: 'json',
        contentType: "application/json; charset=utf-8"
      });
    },
    removeConfig: function (ruleId) {
      return $.ajax({
        type: "delete",
        url: this.baseServiceUrl() + "/" + ruleId,
        dataType: 'json',
        contentType: "application/json; charset=utf-8"
      });
    },
    getEvents: function (projectKey) {
      return $.ajax({
        type: "get",
        url: this.baseServiceUrl() + "/events/" + projectKey,
        dataType: 'json',
        contentType: "application/json; charset=utf-8"
      });
    },
    getContextVariables: function (projectKey) {
      return $.ajax({
        type: "get",
        url: this.baseServiceUrl() + "/contexts/" + projectKey,
        dataType: 'json',
        contentType: "application/json; charset=utf-8"
      });
    },
    getRules: function (projectKey) {
      return $.ajax({
        type: "get",
        url: this.baseServiceUrl() + "/rules/" + projectKey,
        dataType: 'json',
        contentType: "application/json; charset=utf-8"
      });
    },
    getConfigMaps: function (projectKey) {
      return $.ajax({
        type: "get",
        url: this.baseServiceUrl() + "/config-maps/" + projectKey,
        dataType: 'json',
        contentType: "application/json; charset=utf-8"
      });
    },
    getConfigMap: function (projectKey, key) {
      return $.ajax({
        type: "get",
        url: this.baseServiceUrl() + "/config-maps/" + projectKey + "/" + key,
        dataType: 'json',
        contentType: "application/json; charset=utf-8"
      });
    },
    removeConfigMap: function (projectKey, key) {
      return $.ajax({
        type: "delete",
        url: this.baseServiceUrl() + "/config-maps/" + projectKey + "/" + key,
        dataType: 'json',
        contentType: "application/json; charset=utf-8"
      });
    },
    saveConfigMap: function (configMap) {
      return $.ajax({
        type: "post",
        url: this.baseServiceUrl() + "/config-maps/",
        dataType: 'json',
        data: JSON.stringify(configMap),
        contentType: "application/json; charset=utf-8"
      });
    },
    validateConfigMap: function (projectKey, key) {
      return $.ajax({
        type: "post",
        url: this.baseServiceUrl() + "/validate-config-map/" + projectKey + "/" + key,
        dataType: 'json',
        contentType: "application/json; charset=utf-8"
      });
    },
    getActions: function (projectKey) {
      return $.ajax({
        type: "get",
        url: this.baseServiceUrl() + "/actions/" + projectKey,
        dataType: 'json',
        contentType: "application/json; charset=utf-8"
      });
    },
    testPostScript: function (script, type) {
      var param = {
        script: script
      };
      return $.ajax({
        type: "post",
        url: this.baseServiceUrl() + "/validate/" + type,
        dataType: 'json',
        data: JSON.stringify(param),
        contentType: "application/json; charset=utf-8"
      });
    },
    jqlautocompletedata: function () {
      return $.ajax({
        type: "get",
        url: AJS.contextPath() + "/rest/api/2/jql/autocompletedata",
        dataType: 'json',
        contentType: "application/json; charset=utf-8"
      });
    },
  };
});
